@@ -1,7 +1,7 @@
 ## ============================================================================
 ## Author:           Gregoire Thomas
 ## Created:          2014-10-27
-## Last Modified:    2025-06-04
+## Last Modified:    2025-11-24
 ## Copyright (c) 2014-2025 SQU4RE  - http://www.squ4re.com/
 ## 
 ## This program is free software: you can redistribute it and/or modify it 
@@ -26,8 +26,8 @@
 #' the package pROC. 
 #'
 #' @inheritParams alternativeROC-common-args
-#' @param x Numeric vector containing the predicted value for each observation, or a matrix with \code{boot.n} columns containing bootstrap predicted values. 
-#' @param y Factor, numeric, logical or character vector encoding the response. 
+#' @param x Numeric vector containing the predicted value for each observation, or a matrix with \code{boot.n} columns containing bootstrap predicted values, or a na object of type \code{pROC::roc}. 
+#' @param y Factor, numeric, logical or character vector encoding the response. Ignore is \code{x} is of type \code{pROC::roc}.
 #' @param sensitivities Vector of sensitivity thresholds. Default NULL. 
 #' @param specificities Vector of specificity thresholds. Default NULL.  
 #' @param fun Function to compute additional statistics. Default NULL.
@@ -38,6 +38,7 @@
 #' @param parallel Parallelise bootstrap. Default FALSE.
 #' @param simplify If TRUE, return only median for results of the function \code{fun} having one value across bootstraps. Default TRUE.
 #' @param direction Direction of the ROC curve, see \code{pROC::roc}. Default "auto".
+#' @param quiet Disable validity check of \code{boot.n}. Default TRUE.
 #' @param ... Additional arguments passed to \code{fun} if not NULL.
 #' 
 #' @details
@@ -131,7 +132,7 @@
 #'
 #' @export 
 #'
-rocperf <- function(x,y,
+rocperf <- function(x,y=NULL,
                     sensitivities=NULL,
                     specificities=NULL,
                     conf.level=.95,
@@ -143,7 +144,21 @@ rocperf <- function(x,y,
                     parallel=FALSE,
                     simplify=TRUE,
                     direction="auto",
+                    quiet=FALSE,
                     ...) {
+  ## ==========
+  x0 <- NULL
+  if(inherits(x,"roc")) {
+    x0 <- x
+    x <- c(x0$cases,x0$controls)
+    y <- c(rep(1,length(x0$cases)),
+           rep(0,length(x0$controls)))
+    direction <- x0$direction
+  } else if(is.null(y)) stop("missing parameter 'y'")
+  ## ==========
+  if(!quiet&&((1-conf.level)*boot.n<40))
+    warning(sprintf("the number of bootstrap samples %d is too low for conf.level %.02f",boot.n,conf.level))
+  ## ==========
   if(boot.n<1) {
     stop("boot.n must be at least 1")
   } else if(boot.n==1) median <- FALSE
