@@ -51,5 +51,15 @@ test_that("rocperf",{
     testthat::expect_false((d>to)&&(d>1e-2))
   }
   ## ========================================================
+  set.seed(123)
+  co <- rnorm(12)
+  ca <- rnorm(23)
+  y <- c(rep(0,length(co)),rep(1,length(ca)))
+  x <- c(co,ca)
+  r <- pROC::roc(y,x)
+  p <- rocperf(r,boot.n=10,quiet=TRUE)
+  q <- rocperf(x,y,boot.n=10,quiet=TRUE)
+  testthat::expect_true(all(abs(r$auc-c(p$AUC,q$AUC))<1e9))
+  ## ========================================================
 })
 
